@@ -2,7 +2,7 @@
 
 APP='Connectagram'
 BUNDLE="$APP.app"
-VERSION='1.2.8'
+VERSION='1.2.9'
 
 # Remove any previous disk folder or DMG
 echo -n 'Preparing... '
@@ -35,7 +35,7 @@ echo >> "$APP/Read Me.txt"
 echo 'NEWS' >> "$APP/Read Me.txt"
 echo '====' >> "$APP/Read Me.txt"
 echo >> "$APP/Read Me.txt"
-cat NEWS >> "$APP/Read Me.txt"
+cat ChangeLog >> "$APP/Read Me.txt"
 echo 'Done'
 
 # Copy translations
