@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2012, 2013, 2014, 2015, 2016 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2012, 2013, 2014, 2015, 2016, 2017, 2018 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -67,7 +67,7 @@ Window::Window() {
 	QFont f = font();
 	f.setPointSize(24);
 	QFontMetrics metrics(f);
-	int width = metrics.width(tr("Success"));
+	int width = metrics.boundingRect(tr("Success")).width();
 	int height = metrics.height();
 	int ratio = devicePixelRatio();
 	QPixmap pixmap(QSize(width + height, height * 2) * ratio);
@@ -96,12 +96,12 @@ Window::Window() {
 	f = font();
 	f.setPixelSize(20);
 	metrics = QFontMetrics(f);
-	width = std::max(metrics.width(tr("Loading")), metrics.width(tr("Paused")));
+	width = std::max(metrics.boundingRect(tr("Loading")).width(), metrics.boundingRect(tr("Paused")).width());
 	for (int i = 0; i < 10; ++i) {
 		QString test(6, QChar(i + 48));
 		test.insert(4, QLatin1Char(':'));
 		test.insert(2, QLatin1Char(':'));
-		width = std::max(width, metrics.width(test));
+		width = std::max(width, metrics.boundingRect(test).width());
 	}
 	pixmap = QPixmap(QSize(width + 82, 32) * ratio);
 	pixmap.setDevicePixelRatio(ratio);
@@ -262,7 +262,7 @@ void Window::about() {
 	QMessageBox::about(this, tr("About"), QString("<p><center><big><b>%1 %2</b></big><br/>%3<br/><small>%4<br/>%5</small></center></p><p><center>%6</center></p>")
 		.arg(tr("Connectagram"), QCoreApplication::applicationVersion(),
 			tr("A word unscrambling game"),
-			tr("Copyright &copy; 2009-%1 by Graeme Gott").arg("2016"),
+			tr("Copyright &copy; 2009-%1 by Graeme Gott").arg("2018"),
 			tr("Released under the <a href=\"http://www.gnu.org/licenses/gpl.html\">GPL 3</a> license"),
 			tr("Definitions are from <a href=\"http://wiktionary.org/\">Wiktionary</a>"))
 	);
